summaryrefslogtreecommitdiffstats
path: root/src/widgets/qlistbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/qlistbox.cpp')
-rw-r--r--src/widgets/qlistbox.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/widgets/qlistbox.cpp b/src/widgets/qlistbox.cpp
index 314855271..c8ca44c91 100644
--- a/src/widgets/qlistbox.cpp
+++ b/src/widgets/qlistbox.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -835,7 +835,7 @@ int TQListBoxPixmap::rtti() const
setCurrentItem().
The list box normally arranges its items in a single column and
- adds a vertical scroll bar if retquired. It is possible to have a
+ adds a vertical scroll bar if required. It is possible to have a
different fixed number of columns (setColumnMode()), or as many
columns as will fit in the list box's assigned screen space
(setColumnMode(FitToWidth)), or to have a fixed number of rows
@@ -963,8 +963,8 @@ int TQListBoxPixmap::rtti() const
\value FitToHeight There are as many rows as will fit on-screen.
- \value Variable There are as many rows as are retquired by the
- column mode. (Or as many columns as retquired by the row mode.)
+ \value Variable There are as many rows as are required by the
+ column mode. (Or as many columns as required by the row mode.)
Example: When you call setRowMode( FitToHeight ), columnMode()
automatically becomes \c Variable to accommodate the row mode
@@ -2317,7 +2317,7 @@ void TQListBox::mouseMoveEvent( TQMouseEvent *e )
d->scrollTimer->start( 100, FALSE );
doAutoScroll();
} else if ( !d->scrollTimer ) {
// or just select the retquired bits
updateSelection();
}
}
@@ -2317,7 +2317,7 @@ void TQListBox::mouseMoveEvent( TQMouseEvent *e )
doAutoScroll();
} else if ( !d->scrollTimer ) {
- // or just select the retquired bits
+ // or just select the required bits
updateSelection();
}